@@ -5,9 +5,14 @@
 #include <gnome.h>
 #include <glibtop/procopenfiles.h>
 #include <sys/stat.h>
+#include <netdb.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <arpa/inet.h>
 #include "procman.h"
 #include "openfiles.h"
 #include "proctable.h"
+#include "util.h"
 
 enum
 {
@@ -29,7 +34,7 @@ get_type_name(enum glibtop_file_type t)
 	case GLIBTOP_FILE_TYPE_PIPE:
 		return _("pipe");
 	case GLIBTOP_FILE_TYPE_INETSOCKET:
-		return _("internet connection");
+		return _("network connection");
 	case GLIBTOP_FILE_TYPE_LOCALSOCKET:
 		return _("local socket");
 	default:
@@ -38,6 +43,31 @@ get_type_name(enum glibtop_file_type t)
 }
 
 
+
+static char *
+friendlier_hostname(const char *dotted_quad, int port)
+{
+	struct in_addr addr4;
+	struct hostent *host;
+
+	if(inet_pton(AF_INET, dotted_quad, &addr4) <= 0)
+		goto failsafe;
+
+
+	host = gethostbyaddr(&addr4, sizeof addr4, AF_INET);
+
+	if(!host)
+		goto failsafe;
+
+	return g_strdup_printf("%s:%d", host->h_name, port);
+
+ failsafe:
+	if(!dotted_quad[0]) return g_strdup("");
+	return g_strdup_printf("%s:%d", dotted_quad, port);
+}
+
+
+
 static void
 add_new_files (gpointer key, gpointer value, gpointer data)
 {
@@ -46,20 +76,25 @@ add_new_files (gpointer key, gpointer value, gpointer data)
 	GtkTreeModel *model = data;
 	GtkTreeIter row;
 
-	const char *object = "";
-	char buf[100];
+	char *object;
 
+	switch(openfiles->type)
+	{
+	case GLIBTOP_FILE_TYPE_FILE:
+		object = g_strdup(openfiles->info.file.name);
+		break;
 
-	if(openfiles->type == GLIBTOP_FILE_TYPE_FILE)
-	{
-		object = openfiles->info.file.name;
-	}
-	else if(openfiles->type == GLIBTOP_FILE_TYPE_INETSOCKET)
-	{
-		object = buf;
-		g_snprintf(buf, sizeof buf, "%s:%d",
-			   openfiles->info.sock.dest_host,
-			   openfiles->info.sock.dest_port);
+	case GLIBTOP_FILE_TYPE_INETSOCKET:
+		object = friendlier_hostname(openfiles->info.sock.dest_host,
+					     openfiles->info.sock.dest_port);
+		break;
+
+	case GLIBTOP_FILE_TYPE_LOCALSOCKET:
+		object = g_strdup(openfiles->info.localsock.name);
+		break;
+
+	default:
+		object = g_strdup("");
 	}
 
 	gtk_list_store_insert (GTK_LIST_STORE (model), &row, 0);
@@ -69,6 +104,8 @@ add_new_files (gpointer key, gpointer value, gpointer data)
 			    COL_OBJECT, object,
 			    COL_OPENFILE_STRUCT, g_memdup(openfiles, sizeof(*openfiles)),
 			    -1);
+
+	g_free(object);
 }
 
 static GList *old_maps = NULL;
@@ -181,15 +218,23 @@ create_openfiles_tree (ProcData *procdata)
 	GtkCellRenderer *cell;
 	gint i;
 
-	static gchar *title[] = {
+	static const gchar *title[] = {
+		/* Translators: "FD" here means "File Descriptor". Please use
+                   a very short translation if possible, and at most
+                   2-3 characters for it to be able to fit in the UI. */
 		N_("FD"),
 		N_("Type"),
 		N_("Object")
 	};
 
+	PROCMAN_GETTEXT_ARRAY_INIT(title);
+
 	model = gtk_list_store_new (NUM_OPENFILES_COL,
-				    G_TYPE_INT, G_TYPE_STRING,
-				    G_TYPE_STRING, G_TYPE_POINTER);
+				    G_TYPE_INT,		/* FD */
+				    G_TYPE_STRING,	/* Type */
+				    G_TYPE_STRING,	/* Object */
+				    G_TYPE_POINTER	/* open_files_entry */
+		);
 
 	tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree), TRUE);
@@ -270,7 +315,7 @@ create_single_openfiles_dialog (GtkTreeModel *model, GtkTreePath *path,
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
 	dialog_vbox = gtk_vbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 12);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 5);
 	gtk_box_pack_start (GTK_BOX (vbox), dialog_vbox, TRUE, TRUE, 0);
 
 	cmd_hbox = gtk_hbox_new (FALSE, 12);
@@ -286,6 +331,8 @@ create_single_openfiles_dialog (GtkTreeModel *model, GtkTreePath *path,
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+                                             GTK_SHADOW_IN);
 
 	tree = create_openfiles_tree (procdata);
 	gtk_container_add (GTK_CONTAINER (scrolled), tree);
