@@ -187,8 +187,8 @@ struct _ProcData
 	GtkWidget	*app;
 };
 
-void		procman_save_config (ProcData *data);
-void		procman_save_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix);
-gboolean	procman_get_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix);
+void		procman_save_config (ProcData *data) G_GNUC_INTERNAL;
+void		procman_save_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix) G_GNUC_INTERNAL;
+gboolean	procman_get_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix) G_GNUC_INTERNAL;
 
 #endif /* _PROCMAN_PROCMAN_H_ */
